Index: /trunk/Doxyfile.Core
===================================================================
--- /trunk/Doxyfile.Core	(revision 25644)
+++ /trunk/Doxyfile.Core	(revision 25645)
@@ -434,4 +434,13 @@
 PREDEFINED            += HCPTRTYPE(HCType)=HCType
 PREDEFINED            += R3R0PTRTYPE(R3R0Type)=R3R0Type
+# Compile assertion hacks.
+PREDEFINED            += \
+    AssertCompile(expr) \
+    AssertCompileSize(a,b) \
+    AssertCompileSizeAlignment(a,b) \
+    AssertCompileMemberSizeAlignment(a,b,c) \
+    AssertCompileMemberAlignment(a,b,c) \
+    AssertCompileMemberOffset(a,b,c) \
+    AssertCompile2MemberOffsets(a,b,c)
 # COM/XPCOM hacks.
 PREDEFINED            += STDMETHODIMP=HRESULT
@@ -519,4 +528,6 @@
     DECLR0CALLBACKMEMBER \
     DECLINLINE \
+    DECL_FORCE_INLINE \
+    DECLHIDDEN \
     CTXSUFF \
     OTHERCTXSUFF \
Index: /trunk/include/iprt/assert.h
===================================================================
--- /trunk/include/iprt/assert.h	(revision 25644)
+++ /trunk/include/iprt/assert.h	(revision 25645)
@@ -137,9 +137,9 @@
 RTDECL(void)    RTAssertMsg2Add(const char *pszFormat, ...);
 /**
- * Weak version of RTAssertMsgAdd2 that forwards to RTAssertMsg2AddWeakV.
+ * Weak version of RTAssertMsg2Add that forwards to RTAssertMsg2AddWeakV.
  *
  * There is not need to override this, check out RTAssertMsg2AddWeakV instead!
  *
- * @copydoc RTAssertMsgAdd2
+ * @copydoc RTAssertMsg2Add
  */
 RTDECL(void)    RTAssertMsg2AddWeak(const char *pszFormat, ...);
@@ -434,5 +434,5 @@
 #endif
 
-/** @def rtAssertPanic()
+/** @def RTAssertPanic()
  * If RT_STRICT is defined this macro will invoke RTAssertDoPanic if
  * RTAssertShouldPanic returns true. If RT_STRICT isn't defined it won't do any
Index: /trunk/include/iprt/cache.h
===================================================================
--- /trunk/include/iprt/cache.h	(revision 25644)
+++ /trunk/include/iprt/cache.h	(revision 25645)
@@ -104,12 +104,12 @@
  *
  * @returns iprt status code.
- * @param   ppObjCache    Where to store the pointer to the created cache.
- * @param   cElements     Number of elements the cache can hold.
- *                        0 if unlimited size.
- * @param   cbElement     Size of one element in bytes
- * @param   fProt         Protection flags for protecting cache against concurrent access
- *                        from different threads.
- *                        RTOBJCACHE_PROTECT_REQUEST   to protect the request function.
- *                        RTOBJCACHE_PROTECT_INSERT    to protect the insert function.
+ * @param   ppCache         Where to store the pointer to the created cache.
+ * @param   cElements       Number of elements the cache can hold.
+ *                          0 if unlimited size.
+ * @param   cbElement       Size of one element in bytes
+ * @param   fProt           Protection flags for protecting cache against
+ *                          concurrent access from different threads.
+ *                          RTOBJCACHE_PROTECT_REQUEST   to protect the request function.
+ *                          RTOBJCACHE_PROTECT_INSERT    to protect the insert function.
  */
 RTDECL(int) RTCacheCreate(PRTOBJCACHE *ppCache, uint32_t cElements, size_t cbElement, uint32_t fProt);
Index: /trunk/include/iprt/cdefs.h
===================================================================
--- /trunk/include/iprt/cdefs.h	(revision 25644)
+++ /trunk/include/iprt/cdefs.h	(revision 25645)
@@ -465,5 +465,5 @@
  * between R3, R0 and/or RC. The intention is to avoid the \#ifdef IN_RC mess.
  *
- * @param   pR0String   The RC string. Only referenced in RC.
+ * @param   pRCString   The RC string. Only referenced in RC.
  * @see R3STRING, R0STRING
  */
@@ -568,5 +568,5 @@
  * @param   type    The return type of the function or the data type of the variable.
  */
-#if defined(RT_OS_OS2) || defined(RT_OS_WINDOWS) || !defined(RT_USE_VISIBILITY_HIDDEN)
+#if defined(RT_OS_OS2) || defined(RT_OS_WINDOWS) || !defined(RT_USE_VISIBILITY_HIDDEN) || defined(DOXYGEN_RUNNING)
 # define DECLHIDDEN(type)       type
 #else
@@ -1098,5 +1098,5 @@
  * Convert a pointer to a structure member into a pointer to the structure.
  * @returns pointer to the structure.
- * @param   pMember Pointer to the member.
+ * @param   pMem    Pointer to the member.
  * @param   Type    Strucutre type.
  * @param   Member  Member name.
Index: /trunk/include/iprt/critsect.h
===================================================================
--- /trunk/include/iprt/critsect.h	(revision 25644)
+++ /trunk/include/iprt/critsect.h	(revision 25645)
@@ -138,5 +138,7 @@
  * @param   pCritSect       The critical section.
  * @param   uId             Where we're entering the section.
- * @param   RT_SRC_POS_DECL The source position.
+ * @param   pszFile         The source position - file.
+ * @param   iLine           The source position - line.
+ * @param   pszFunction     The source position - function.
  */
 RTDECL(int) RTCritSectEnterDebug(PRTCRITSECT pCritSect, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -164,5 +166,7 @@
  * @param   pCritSect       The critical section.
  * @param   uId             Where we're entering the section.
- * @param   RT_SRC_POS_DECL The source position.
+ * @param   pszFile         The source position - file.
+ * @param   iLine           The source position - line.
+ * @param   pszFunction     The source position - function.
  */
 RTDECL(int) RTCritSectTryEnterDebug(PRTCRITSECT pCritSect, RTHCUINTPTR uId, RT_SRC_POS_DECL);
@@ -197,5 +201,7 @@
  * @param   papCritSects    Array of critical section pointers.
  * @param   uId             Where we're entering the section.
- * @param   RT_SRC_POS_DECL The source position.
+ * @param   pszFile         The source position - file.
+ * @param   iLine           The source position - line.
+ * @param   pszFunction     The source position - function.
  *
  * @remark  See RTCritSectEnterMultiple().
Index: /trunk/include/iprt/file.h
===================================================================
--- /trunk/include/iprt/file.h	(revision 25644)
+++ /trunk/include/iprt/file.h	(revision 25645)
@@ -260,5 +260,5 @@
  *
  * @return  The native handle.
- * @params  File            The IPRT file handle.
+ * @param   File            The IPRT file handle.
  */
 RTR3DECL(RTHCINTPTR) RTFileToNative(RTFILE File);
@@ -1035,11 +1035,11 @@
  * @param   hFile           The file to write to.
  * @param   off             The offset to start writing at.
- * @param   pvBuf           Where to store the written bits.
- * @param   cbRead          Number of bytes to write.
+ * @param   pvBuf           The bits to write.
+ * @param   cbWrite         Number of bytes to write.
  * @param   pvUser          Opaque user data associated with this request which
  *                          can be retrieved with RTFileAioReqGetUser().
  */
 RTDECL(int) RTFileAioReqPrepareWrite(RTFILEAIOREQ hReq, RTFILE hFile, RTFOFF off,
-                                     void *pvBuf, size_t cbWrite, void *pvUser);
+                                     void const *pvBuf, size_t cbWrite, void *pvUser);
 
 /**
@@ -1094,5 +1094,5 @@
  *                          requests.
  */
-RTDECL(int) RTFileAioReqGetRC(RTFILEAIOREQ hReq, size_t *pcbTransfered);
+RTDECL(int) RTFileAioReqGetRC(RTFILEAIOREQ hReq, size_t *pcbTransferred);
 
 
Index: /trunk/include/iprt/handletable.h
===================================================================
--- /trunk/include/iprt/handletable.h	(revision 25644)
+++ /trunk/include/iprt/handletable.h	(revision 25645)
@@ -113,5 +113,5 @@
  *          location phHandleTable points at.
  *
- * @param   pHandleTable    Where to store the handle table handle on success.
+ * @param   phHandleTable   Where to store the handle table handle on success.
  * @param   fFlags          Flags, see RTHANDLETABLE_FLAGS_*.
  * @param   uBase           The handle base value. This is the value of the
@@ -136,5 +136,5 @@
  * @returns IPRT status code and *phHandleTable.
  *
- * @param   pHandleTable    Where to store the handle table handle on success.
+ * @param   phHandleTable   Where to store the handle table handle on success.
  */
 RTDECL(int)     RTHandleTableCreate(PRTHANDLETABLE phHandleTable);
Index: /trunk/include/iprt/initterm.h
===================================================================
--- /trunk/include/iprt/initterm.h	(revision 25644)
+++ /trunk/include/iprt/initterm.h	(revision 25645)
@@ -57,5 +57,4 @@
  *
  * @returns IPRT status code.
- * @param   pszProgramPath      The path to the program file.
  *
  * @remarks Failure to initialize SUPLib is ignored.
Index: /trunk/include/iprt/linux/sysfs.h
===================================================================
--- /trunk/include/iprt/linux/sysfs.h	(revision 25644)
+++ /trunk/include/iprt/linux/sysfs.h	(revision 25645)
@@ -40,5 +40,5 @@
 RT_C_DECLS_BEGIN
 
-/** @defgroup grp_rt_mp RTLinuxSysfs - Linux sysfs
+/** @defgroup grp_rt_linux_sysfs    RTLinuxSysfs - Linux sysfs
  * @ingroup grp_rt
  * @{
Index: /trunk/include/iprt/localipc.h
===================================================================
--- /trunk/include/iprt/localipc.h	(revision 25644)
+++ /trunk/include/iprt/localipc.h	(revision 25645)
@@ -123,5 +123,5 @@
  *
  * @returns IPRT status code.
- * @param   VINF_SUCCESS on success and *phSession holding the session handle.
+ * @retval  VINF_SUCCESS on success and *phSession holding the session handle.
  *
  * @param   phSession           Where to store the sesson handle on success.
@@ -270,5 +270,5 @@
  * @param   pGid                Where to store the group ID on success.
  */
-RTDECL(int) RTLocalIpcSessionQueryGroupId(RTLOCALIPCSESSION hSession, PRTUID pUid);
+RTDECL(int) RTLocalIpcSessionQueryGroupId(RTLOCALIPCSESSION hSession, PRTGID pGid);
 
 /** @} */
Index: /trunk/include/iprt/lockvalidator.h
===================================================================
--- /trunk/include/iprt/lockvalidator.h	(revision 25644)
+++ /trunk/include/iprt/lockvalidator.h	(revision 25645)
@@ -37,5 +37,5 @@
 
 
-/** @defgroup grp_ldr       RTLockValidator - Lock Validator
+/** @defgroup grp_rtlockval     RTLockValidator - Lock Validator
  * @ingroup grp_rt
  * @{
@@ -572,5 +572,5 @@
  * Removes all current owners and makes hThread the only owner.
  *
- * @param   pRead               The validator record.
+ * @param   pRec                The validator record.
  * @param   hThread             The thread handle of the owner.  NIL_RTTHREAD is
  *                              an alias for the current thread.
@@ -585,5 +585,5 @@
  * acquiring the lock in shared mode.
  *
- * @param   pRead               The validator record.
+ * @param   pRec                The validator record.
  * @param   hThread             The thread handle of the owner.  NIL_RTTHREAD is
  *                              an alias for the current thread.
Index: /trunk/include/iprt/mem.h
===================================================================
--- /trunk/include/iprt/mem.h	(revision 25644)
+++ /trunk/include/iprt/mem.h	(revision 25645)
@@ -265,5 +265,5 @@
  *
  * @param   pvDst       The kernel mode destination address.
- * @param   R3PtrDst    The user mode source address.
+ * @param   R3PtrSrc    The user mode source address.
  * @param   cb          The number of bytes to copy.
  */
@@ -446,5 +446,5 @@
  * chokes on it with an internal compiler error.
  *
- * @param   T           The data type that's being managed.
+ * @tparam  T           The data type that's being managed.
  * @param   aMem        Pointer to the memory that should be free.
  */
@@ -477,5 +477,5 @@
  * chokes on it with an internal compiler error.
  *
- * @param   T           The data type that's being managed.
+ * @tparam  T           The data type that's being managed.
  * @param   aMem        Pointer to the memory that should be free.
  */
@@ -494,5 +494,5 @@
  * chokes on it with an internal compiler error.
  *
- * @param   T           The data type that's being managed.
+ * @tparam  T           The data type that's being managed.
  * @param   aMem        Pointer to the memory that should be free.
  */
@@ -508,5 +508,5 @@
  * for RTAutoRes.
  *
- * @param   T           The data type that's being managed.
+ * @tparam  T           The data type that's being managed.
  * @returns NULL with the right type.
  */
@@ -529,8 +529,8 @@
  * you hand it.
  *
- * @param   T           The data type to manage allocations for.
- * @param   Destruct    The function to be used to free the resource.
+ * @tparam  T           The data type to manage allocations for.
+ * @tparam  Destruct    The function to be used to free the resource.
  *                      This will default to RTMemFree.
- * @param   Allocator   The function to be used to allocate or reallocate
+ * @tparam  Allocator   The function to be used to allocate or reallocate
  *                      the managed memory.
  *                      This is standard realloc() like stuff, so it's possible
@@ -643,8 +643,8 @@
      * @retval  false on failure, no memory is associated with the object.
      *
-     * @param   cElements   The new number of elements (of the data type) to allocate.
-     *                      The size of the allocation is the number of elements times
-     *                      the size of the data type - this is currently what's passed
-     *                      down to the Allocator.
+     * @param   a_cElements The new number of elements (of the data type) to
+     *                      allocate. The size of the allocation is the number of
+     *                      elements times the size of the data type - this is
+     *                      currently what's passed down to the Allocator.
      *                      This defaults to 1.
      */
Index: /trunk/include/iprt/net.h
===================================================================
--- /trunk/include/iprt/net.h	(revision 25644)
+++ /trunk/include/iprt/net.h	(revision 25645)
@@ -417,5 +417,5 @@
 /**
  * IPv4 DHCP packet.
- * @obsolete Use RTNETBOOTP.
+ * @deprecated Use RTNETBOOTP.
  */
 #pragma pack(1)
Index: /trunk/include/iprt/path.h
===================================================================
--- /trunk/include/iprt/path.h	(revision 25644)
+++ /trunk/include/iprt/path.h	(revision 25645)
@@ -269,6 +269,6 @@
  *
  * @param   pszPath     Path to find filename in.
- * @param   pcbDir      Where to put the length of the directory component.
- *                      If no directory, this will be 0. Optional.
+ * @param   pcchDir     Where to put the length of the directory component. If
+ *                      no directory, this will be 0. Optional.
  * @param   poffName    Where to store the filename offset.
  *                      If empty string or if it's ending with a slash this
@@ -277,6 +277,4 @@
  *                      If empty string or if it's ending with a slash this
  *                      will be set to -1. Optional.
- * @param   pfFlags     Where to set flags returning more information about
- *                      the path. For the future. Optional.
  */
 RTDECL(size_t) RTPathParse(const char *pszPath, size_t *pcchDir, ssize_t *poffName, ssize_t *poffSuff);
Index: /trunk/include/iprt/rand.h
===================================================================
--- /trunk/include/iprt/rand.h	(revision 25644)
+++ /trunk/include/iprt/rand.h	(revision 25645)
@@ -118,5 +118,6 @@
  *
  * @returns IPRT status code.
- * @param   hRand       Handle to the random number generator.
+ * @param   phRand      Where to return the handle to the new random number
+ *                      generator.
  */
 RTDECL(int) RTRandAdvCreate(PRTRAND phRand) RT_NO_THROW;
Index: /trunk/include/iprt/s3.h
===================================================================
--- /trunk/include/iprt/s3.h	(revision 25644)
+++ /trunk/include/iprt/s3.h	(revision 25645)
@@ -265,5 +265,5 @@
  * @param   pszFilename     Name of the file to upload the content of.
  */
-RTR3DECL(int) RTS3PutKey(RTS3 hS3, const char *pszBucketName, const char *pszKeyName, const char *pszFileName);
+RTR3DECL(int) RTS3PutKey(RTS3 hS3, const char *pszBucketName, const char *pszKeyName, const char *pszFilename);
 
 /** @} */
Index: /trunk/include/iprt/semaphore.h
===================================================================
--- /trunk/include/iprt/semaphore.h	(revision 25644)
+++ /trunk/include/iprt/semaphore.h	(revision 25645)
@@ -250,5 +250,5 @@
 
 
-/** @defgroup grp_rt_sems_mutex     RTMutex - Mutex semaphores.
+/** @defgroup grp_rt_sems_mutex     RTSemMutex - Mutex semaphores.
  *
  * Mutex semaphores protect a section of code or data to which access must be
@@ -661,5 +661,5 @@
  *                              from.  Optional.
  */
-RTDECL(int)  RTSemRWRequestWriteDebug(RTSEMRW MutexSem, unsigned cMillies, RTHCUINTPTR uId, RT_SRC_POS_DECL);
+RTDECL(int)  RTSemRWRequestWriteDebug(RTSEMRW RWSem, unsigned cMillies, RTHCUINTPTR uId, RT_SRC_POS_DECL);
 
 /**
Index: /trunk/include/iprt/test.h
===================================================================
--- /trunk/include/iprt/test.h	(revision 25644)
+++ /trunk/include/iprt/test.h	(revision 25645)
@@ -244,5 +244,5 @@
  * @param   va              Arguments for the reason format string.
  */
-RTR3DECL(int) RTTestSkipAndDestroyV(RTTEST hTest, const char *pszReason, va_list va);
+RTR3DECL(int) RTTestSkipAndDestroyV(RTTEST hTest, const char *pszReasonFmt, va_list va);
 
 /**
@@ -253,7 +253,7 @@
  *                          associated with the calling thread.
  * @param   pszReasonFmt    Text explaining why, optional (NULL).
- * @param   va              Arguments for the reason format string.
- */
-RTR3DECL(int) RTTestSkipAndDestroy(RTTEST hTest, const char *pszReason, ...);
+ * @param   ...             Arguments for the reason format string.
+ */
+RTR3DECL(int) RTTestSkipAndDestroy(RTTEST hTest, const char *pszReasonFmt, ...);
 
 /**
@@ -292,5 +292,5 @@
  *                          associated with the calling thread.
  * @param   pszSubTestFmt   The sub-test name format string.
- * @param   ...             Arguments.
+ * @param   va              Arguments.
  */
 RTR3DECL(int) RTTestSubV(RTTEST hTest, const char *pszSubTestFmt, va_list va);
@@ -380,5 +380,4 @@
  * @param   hTest       The test handle. If NIL_RTTEST we'll use the one
  *                      associated with the calling thread.
- * @param   enmLevel    Message importance level.
  * @param   pszFormat   The message.
  * @param   va          Arguments.
@@ -392,5 +391,4 @@
  * @param   hTest       The test handle. If NIL_RTTEST we'll use the one
  *                      associated with the calling thread.
- * @param   enmLevel    Message importance level.
  * @param   pszFormat   The message.
  * @param   ...         Arguments.
@@ -668,5 +666,5 @@
  * @returns Number of chars printed.
  * @param   pszSubTestFmt   The sub-test name format string.
- * @param   ...             Arguments.
+ * @param   va              Arguments.
  */
 RTR3DECL(int) RTTestISubV(const char *pszSubTestFmt, va_list va);
Index: /trunk/include/iprt/types.h
===================================================================
--- /trunk/include/iprt/types.h	(revision 25644)
+++ /trunk/include/iprt/types.h	(revision 25645)
@@ -1026,5 +1026,5 @@
 /** Raw mode context pointer, unsigned integer variant. */
 typedef int32_t         RTRCINTPTR;
-/** @def RTRCUINPTR_MAX
+/** @def RTRCUINTPTR_MAX
  * The maximum value a RTRCUINPTR can have.
  */
@@ -1033,9 +1033,9 @@
 /** Raw mode context pointer, signed integer variant. */
 typedef uint32_t        RTRCUINTPTR;
-/** @def RTRCINPTR_MIN
+/** @def RTRCINTPTR_MIN
  * The minimum value a RTRCINPTR can have.
  */
 #define RTRCINTPTR_MIN ((RTRCINTPTR)INT32_MIN)
-/** @def RTRCINPTR_MAX
+/** @def RTRCINTPTR_MAX
  * The maximum value a RTRCINPTR can have.
  */
Index: /trunk/include/iprt/uuid.h
===================================================================
--- /trunk/include/iprt/uuid.h	(revision 25644)
+++ /trunk/include/iprt/uuid.h	(revision 25645)
@@ -77,6 +77,8 @@
  *
  * @returns 0 if eq, < 0 or > 0.
- * @param   pUuid1          First value to compare. NULL is treated like if RTUuidIsNull() return true.
- * @param   pUuid2          Second value to compare. NULL is treated like if RTUuidIsNull() return true.
+ * @param   pUuid1          First value to compare.  NULL is treated like if
+ *                          RTUuidIsNull() return true.
+ * @param   pUuid2          Second value to compare.  NULL is treated like if
+ *                          RTUuidIsNull() return true.
  */
 RTDECL(int)  RTUuidCompare(PCRTUUID pUuid1, PCRTUUID pUuid2);
@@ -87,6 +89,6 @@
  * @note IPRT uses little endian byte ordering in the UUID integer fields. If
  * you want to pass IPRT UUIDs in binary representation to other UUID libraries
- * and expect to get exactly the same string representation as in IPRT, you
- * need to convert the first three integer fields (one 32 bit value, two 16 bit
+ * and expect to get exactly the same string representation as in IPRT, you need
+ * to convert the first three integer fields (one 32 bit value, two 16 bit
  * values) separately to big endian (also called network byte order).
  * Correspondingly, if you want to get the right result with UUIDs which are in
@@ -96,6 +98,7 @@
  *
  * @returns 0 if eq, < 0 or > 0.
- * @param   pUuid1          First value to compare. NULL is not allowed.
- * @param   pszString2      The 2nd UUID in string form. NULL of malformed string is not permitted.
+ * @param   pUuid1          First value to compare.  NULL is not allowed.
+ * @param   pszString       The 2nd UUID in string form.  NULL or malformed
+ *                          string is not permitted.
  */
 RTDECL(int)  RTUuidCompareStr(PCRTUUID pUuid1, const char *pszString);
Index: /trunk/src/VBox/Runtime/Doxyfile
===================================================================
--- /trunk/src/VBox/Runtime/Doxyfile	(revision 25644)
+++ /trunk/src/VBox/Runtime/Doxyfile	(revision 25645)
@@ -1175,7 +1175,16 @@
     RTDECL(type)=type \
     RT_EXPORT_SYMBOL(name)= \
-    DECL_FORCE_INLINE(type)=DECLINLINE(type)
-
-#    DECLCALLBACK(type)=type
+    \
+    "DECLINLINE(type)=inline type" \
+    DECL_FORCE_INLINE(type)=DECLINLINE(type) \
+    \
+    AssertCompile(expr) \
+    AssertCompileSize(a,b) \
+    AssertCompileSizeAlignment(a,b) \
+    AssertCompileMemberSizeAlignment(a,b,c) \
+    AssertCompileMemberAlignment(a,b,c) \
+    AssertCompileMemberOffset(a,b,c) \
+    AssertCompile2MemberOffsets(a,b,c) \
+    \
 
 # If the MACRO_EXPANSION and EXPAND_ONLY_PREDEF tags are set to YES then
@@ -1200,4 +1209,5 @@
     DECLEXPORT \
     DECLIMPORT \
+    DECLHIDDEN \
     DECLASM \
     DECLASMTYPE \
@@ -1208,5 +1218,4 @@
     DECLR3CALLBACKMEMBER \
     DECLR0CALLBACKMEMBER \
-    DECLINLINE \
     RTR3DECL \
     RTR0DECL \
@@ -1220,4 +1229,9 @@
     CTXMID \
     OTHERCTXMID \
+    \
+    RT_SRC_POS \
+    RT_SRC_POS_ARGS \
+    RT_SRC_POS_DECL
+
 
 # If the SKIP_FUNCTION_MACROS tag is set to YES (the default) then
Index: /trunk/src/VBox/Runtime/Makefile.kmk
===================================================================
--- /trunk/src/VBox/Runtime/Makefile.kmk	(revision 25644)
+++ /trunk/src/VBox/Runtime/Makefile.kmk	(revision 25645)
@@ -1727,14 +1727,25 @@
 IPRT_DOXYFILE_INPUT_DIRS = \
 	$(PATH_ROOT)/include/iprt \
+	$(PATH_ROOT)/include/iprt/cpp \
+	$(PATH_ROOT)/include/iprt/linux \
 	$(PATH_ROOT)/include/iprt/nocrt \
 	$(PATH_ROOT)/include/iprt/nocrt/x86 \
 	$(PATH_ROOT)/include/iprt/nocrt/amd64 \
+	$(PATH_ROOT)/include/iprt/nocrt/compiler \
 	$(VBOX_PATH_RUNTIME_SRC)/include/internal \
 	$(VBOX_PATH_RUNTIME_SRC)/common/alloc \
+	$(VBOX_PATH_RUNTIME_SRC)/common/asm \
 	$(VBOX_PATH_RUNTIME_SRC)/common/checksum \
+	$(VBOX_PATH_RUNTIME_SRC)/common/dbg \
 	$(VBOX_PATH_RUNTIME_SRC)/common/err \
 	$(VBOX_PATH_RUNTIME_SRC)/common/ldr \
 	$(VBOX_PATH_RUNTIME_SRC)/common/log \
+	$(VBOX_PATH_RUNTIME_SRC)/common/math \
+	$(VBOX_PATH_RUNTIME_SRC)/common/math/amd64 \
+	$(VBOX_PATH_RUNTIME_SRC)/common/math/gcc \
+	$(VBOX_PATH_RUNTIME_SRC)/common/math/x86 \
 	$(VBOX_PATH_RUNTIME_SRC)/common/misc \
+	$(VBOX_PATH_RUNTIME_SRC)/common/path \
+	$(VBOX_PATH_RUNTIME_SRC)/common/rand \
 	$(VBOX_PATH_RUNTIME_SRC)/common/string \
 	$(VBOX_PATH_RUNTIME_SRC)/common/table \
Index: /trunk/src/VBox/Runtime/VBox/strformat-vbox.cpp
===================================================================
--- /trunk/src/VBox/Runtime/VBox/strformat-vbox.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/VBox/strformat-vbox.cpp	(revision 25645)
@@ -27,39 +27,4 @@
  * Clara, CA 95054 USA or visit http://www.sun.com if you need
  * additional information or have any questions.
- */
-
-/** @page pg_rt_str_format_vbox    The VBox String Format Extensions
- *
- * The string formatter supports most of the non-float format types and flags.
- * See RTStrFormatV() for the full tail there. In addition we've added a number
- * of VBox specific format types. Most of these doesn't work with any flags (like
- * width, precision and such), but they should still be very useful.
- *
- * The types:
- *
- *      - \%Vrc  - Takes an integer iprt status code as argument. Will insert the
- *        status code define corresponding to the iprt status code.
- *      - \%Vrs  - Takes an integer iprt status code as argument. Will insert the
- *        short description of the specified status code.
- *      - \%Vrf  - Takes an integer iprt status code as argument. Will insert the
- *        full description of the specified status code.
- *      - \%Vra  - Takes an integer iprt status code as argument. Will insert the
- *        status code define + full description.
- *      - \%Vt   - Current thread (RTThreadSelf()).
- *      - \%Vhxd - Takes a pointer to the memory which is to be dumped in typical
- *        hex format. Use the width to specify the length, and the precision to
- *        set the number of bytes per line. Default width and precision is 16.
- *      - \%Vhxs - Takes a pointer to the memory to be displayed as a hex string,
- *        i.e. a series of space separated bytes formatted as two digit hex value.
- *        Use the width to specify the length. Default length is 16 bytes.
- *      - \%VGp   - Guest context physical address.
- *      - \%VGv   - Guest context virtual address.
- *      - \%VRv   - 32 bits guest context virtual address.
- *      - \%VHp   - Host context physical address.
- *      - \%VHv   - Host context virtual address.
- *      - \%VI[8|16|32|64] - Signed integer value of the specifed bit count.
- *      - \%VU[8|16|32|64] - Unsigned integer value of the specifed bit count.
- *      - \%VX[8|16|32|64] - Hexadecimal integer value of the specifed bit count.
- *
  */
 
@@ -80,5 +45,7 @@
 /**
  * Callback to format VBox formatting extentions.
- * See @ref pg_rt_str_format_vbox for a reference on the format types.
+ *
+ * @deprecated All the %V* format extensions are deprecated and will be removed
+ *             before long!
  *
  * @returns The number of bytes formatted.
Index: /trunk/src/VBox/Runtime/common/checksum/ipv4.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/checksum/ipv4.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/common/checksum/ipv4.cpp	(revision 25645)
@@ -228,7 +228,7 @@
  *
  * @returns 32-bit intermediary checksum value.
- * @param   pUdpHdr         Pointer to the TCP header to checksum, network endian (big).
- *                          Assums the caller has already validate it and made sure the
- *                          entire header is present.
+ * @param   pTcpHdr         Pointer to the TCP header to checksum, network
+ *                          endian (big). Assums the caller has already validate
+ *                          it and made sure the entire header is present.
  * @param   u32Sum          The 32-bit intermediate checksum value.
  */
@@ -274,7 +274,7 @@
  *
  * @returns 32-bit intermediary checksum value.
- * @param   pUdpHdr         Pointer to the TCP header to checksum, network endian (big).
- *                          Assums the caller has already validate it and made sure the
- *                          entire header is present.
+ * @param   pTcpHdr         Pointer to the TCP header to checksum, network
+ *                          endian (big). Assums the caller has already validate
+ *                          it and made sure the entire header is present.
  * @param   u32Sum          The 32-bit intermediate checksum value.
  */
@@ -290,5 +290,6 @@
  *
  * @returns 32-bit intermediary checksum value.
- * @param   pUdpHdr         Pointer to the UDP header to checksum, network endian (big).
+ * @param   pvData          Pointer to the data that should be checksummed.
+ * @param   cbData          The number of bytes to checksum.
  * @param   u32Sum          The 32-bit intermediate checksum value.
  * @param   pfOdd           This is used to keep track of odd bits, initialize to false
@@ -342,5 +343,6 @@
  *
  * @returns 32-bit intermediary checksum value.
- * @param   pUdpHdr         Pointer to the UDP header to checksum, network endian (big).
+ * @param   pvData          The data bits to checksum.
+ * @param   cbData          The number of bytes to checksum.
  * @param   u32Sum          The 32-bit intermediate checksum value.
  * @param   pfOdd           This is used to keep track of odd bits, initialize to false
Index: /trunk/src/VBox/Runtime/common/dbg/dbgmod.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/dbg/dbgmod.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/common/dbg/dbgmod.cpp	(revision 25645)
@@ -1291,5 +1291,5 @@
  *                              specified address and the returned symbol.
  *                              Optional.
- * @param   pSymInfo            Where to store the symbol information.
+ * @param   pLineInfo           Where to store the line number information.
  */
 RTDECL(int) RTDbgModLineByAddr(RTDBGMOD hDbgMod, RTDBGSEGIDX iSeg, RTUINTPTR off, PRTINTPTR poffDisp, PRTDBGLINE pLineInfo)
Index: /trunk/src/VBox/Runtime/common/dbg/dbgmodcontainer.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/dbg/dbgmodcontainer.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/common/dbg/dbgmodcontainer.cpp	(revision 25645)
@@ -530,5 +530,5 @@
 
 
-/** @copydoc RTDBGMODVTDBG::pfnRvaToSegOff */
+/** @copydoc RTDBGMODVTDBG::pfnImageSize */
 static DECLCALLBACK(RTUINTPTR) rtDbgModContainer_ImageSize(PRTDBGMODINT pMod)
 {
Index: /trunk/src/VBox/Runtime/common/dbg/dbgmodnm.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/dbg/dbgmodnm.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/common/dbg/dbgmodnm.cpp	(revision 25645)
@@ -162,5 +162,5 @@
 
 
-/** @copydoc RTDBGMODVTDBG::pfnRvaToSegOff */
+/** @copydoc RTDBGMODVTDBG::pfnImageSize */
 static DECLCALLBACK(RTUINTPTR) rtDbgModNm_ImageSize(PRTDBGMODINT pMod)
 {
Index: /trunk/src/VBox/Runtime/common/misc/cache.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/misc/cache.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/common/misc/cache.cpp	(revision 25645)
@@ -50,12 +50,12 @@
  *
  * @returns iprt status code.
- * @param   ppObjCache    Where to store the pointer to the created cache.
- * @param   cElements     Number of elements the cache can hold.
- *                        0 if unlimited size.
- * @param   cbElement     Size of one element in bytes
- * @param   fProt         Protection flags for protecting cache against concurrent access
- *                        from different threads.
- *                        RTOBJCACHE_PROTECT_REQUESTER to protect the request function.
- *                        RTOBJCACHE_PROTECT_INSERT    to protect the insert function.
+ * @param   ppCache         Where to store the pointer to the created cache.
+ * @param   cElements       Number of elements the cache can hold.
+ *                          0 if unlimited size.
+ * @param   cbElement       Size of one element in bytes
+ * @param   fProt           Protection flags for protecting cache against
+ *                          concurrent access from different threads.
+ *                          RTOBJCACHE_PROTECT_REQUEST   to protect the request function.
+ *                          RTOBJCACHE_PROTECT_INSERT    to protect the insert function.
  */
 RTDECL(int) RTCacheCreate(PRTOBJCACHE *ppCache, uint32_t cElements, size_t cbElement, uint32_t fProt)
Index: /trunk/src/VBox/Runtime/common/misc/lockvalidator.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/misc/lockvalidator.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/common/misc/lockvalidator.cpp	(revision 25645)
@@ -188,5 +188,7 @@
  * Launch a simple assertion like complaint w/ panic.
  *
- * @param   RT_SRC_POS_DECL     Where from.
+ * @param   pszFile             Where from - file.
+ * @param   iLine               Where from - line.
+ * @param   pszFunction         Where from - function.
  * @param   pszWhat             What we're complaining about.
  * @param   ...                 Format arguments.
@@ -211,6 +213,6 @@
  *
  * @param   pszPrefix           Message prefix.
- * @param   Rec                 The lock record we're working on.
- * @param   pszPrefix           Message suffix.
+ * @param   pRec                The lock record we're working on.
+ * @param   pszSuffix           Message suffix.
  */
 static void rtLockValidatorComplainAboutLock(const char *pszPrefix, PRTLOCKVALRECUNION pRec, const char *pszSuffix)
Index: /trunk/src/VBox/Runtime/common/misc/s3.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/misc/s3.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/common/misc/s3.cpp	(revision 25645)
@@ -863,5 +863,5 @@
 }
 
-RTR3DECL(int) RTS3GetKey(RTS3 hS3, const char* pszBucketName, const char* pszKeyName, const char* pszFileName)
+RTR3DECL(int) RTS3GetKey(RTS3 hS3, const char *pszBucketName, const char *pszKeyName, const char *pszFilename)
 {
     PRTS3INTERNAL pS3Int = hS3;
@@ -873,5 +873,5 @@
     /* Open the file */
     RTFILE hFile;
-    int rc = RTFileOpen(&hFile, pszFileName, RTFILE_O_CREATE | RTFILE_O_WRITE | RTFILE_O_DENY_NONE);
+    int rc = RTFileOpen(&hFile, pszFilename, RTFILE_O_CREATE | RTFILE_O_WRITE | RTFILE_O_DENY_NONE);
     if (RT_FAILURE(rc))
         return rc;
@@ -916,10 +916,10 @@
     /* If there was an error delete the newly created file */
     if (RT_FAILURE(rc))
-        RTFileDelete(pszFileName);
+        RTFileDelete(pszFilename);
 
     return rc;
 }
 
-RTR3DECL(int) RTS3PutKey(RTS3 hS3, const char* pszBucketName, const char* pszKeyName, const char* pszFileName)
+RTR3DECL(int) RTS3PutKey(RTS3 hS3, const char *pszBucketName, const char *pszKeyName, const char *pszFilename)
 {
     PRTS3INTERNAL pS3Int = hS3;
@@ -931,5 +931,5 @@
     /* Open the file */
     RTFILE hFile;
-    int rc = RTFileOpen(&hFile, pszFileName, RTFILE_O_OPEN | RTFILE_O_READ | RTFILE_O_DENY_NONE);
+    int rc = RTFileOpen(&hFile, pszFilename, RTFILE_O_OPEN | RTFILE_O_READ | RTFILE_O_DENY_NONE);
     if (RT_FAILURE(rc))
         return rc;
Index: /trunk/src/VBox/Runtime/common/misc/thread.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/misc/thread.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/common/misc/thread.cpp	(revision 25645)
@@ -779,5 +779,5 @@
  * @param   enmType     See RTThreadCreate.
  * @param   fFlags      See RTThreadCreate.
- * @param   pszName     Thread name format.
+ * @param   pszNameFmt  Thread name format.
  * @param   va          Format arguments.
  */
@@ -804,5 +804,5 @@
  * @param   enmType     See RTThreadCreate.
  * @param   fFlags      See RTThreadCreate.
- * @param   pszName     Thread name format.
+ * @param   pszNameFmt  Thread name format.
  * @param   ...         Format arguments.
  */
Index: /trunk/src/VBox/Runtime/common/path/RTPathParse.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/path/RTPathParse.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/common/path/RTPathParse.cpp	(revision 25645)
@@ -46,6 +46,6 @@
  *
  * @param   pszPath     Path to find filename in.
- * @param   pcbDir      Where to put the length of the directory component.
- *                      If no directory, this will be 0. Optional.
+ * @param   pcchDir     Where to put the length of the directory component. If
+ *                      no directory, this will be 0. Optional.
  * @param   poffName    Where to store the filename offset.
  *                      If empty string or if it's ending with a slash this
@@ -54,6 +54,4 @@
  *                      If empty string or if it's ending with a slash this
  *                      will be set to -1. Optional.
- * @param   pfFlags     Where to set flags returning more information about
- *                      the path. For the future. Optional.
  */
 RTDECL(size_t) RTPathParse(const char *pszPath, size_t *pcchDir, ssize_t *poffName, ssize_t *poffSuff)
Index: /trunk/src/VBox/Runtime/common/string/strformatrt.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/string/strformatrt.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/common/string/strformatrt.cpp	(revision 25645)
@@ -82,5 +82,5 @@
  *      - \%RHx             - Takes a #RTHCUINT or #RTHCINT value, formatting it as hex.
  *      - \%RRv             - Takes a #RTRCPTR, #RTRCINTPTR or #RTRCUINTPTR value.
- *      - \%RCi             - Takes a #RTCCINT value.
+ *      - \%RCi             - Takes a #RTINT value.
  *      - \%RCp             - Takes a #RTCCPHYS value.
  *      - \%RCr             - Takes a #RTCCUINTREG value.
@@ -233,5 +233,5 @@
 #define STRMEM(str) sizeof(str) - 1, str
                     { STRMEM("Ci"),      sizeof(RTINT),          10, RTSF_INT,   RTSTR_F_VALSIGNED },
-                    { STRMEM("Cp"),      sizeof(RTGCPHYS),       16, RTSF_INTW,  0 },
+                    { STRMEM("Cp"),      sizeof(RTCCPHYS),       16, RTSF_INTW,  0 },
                     { STRMEM("Cr"),      sizeof(RTCCUINTREG),    16, RTSF_INTW,  0 },
                     { STRMEM("Cu"),      sizeof(RTUINT),         10, RTSF_INT,   0 },
Index: /trunk/src/VBox/Runtime/include/internal/dbgmod.h
===================================================================
--- /trunk/src/VBox/Runtime/include/internal/dbgmod.h	(revision 25644)
+++ /trunk/src/VBox/Runtime/include/internal/dbgmod.h	(revision 25645)
@@ -38,6 +38,5 @@
 RT_C_DECLS_BEGIN
 
-/** @defgroup grp_rt_dbgmod     RTDbgMod - Debug Module Interperter
- * @ingroup grp_rt
+/** @addtogroup grp_rt_dbgmod
  * @internal
  * @{
@@ -224,4 +223,5 @@
      * @param   off         The offset into the segment.
      * @param   cb          The area covered by the symbol. 0 is fine.
+     * @param   fFlags      Flags.
      * @param   piOrdinal   Where to return the symbol ordinal on success. If the
      *                      interpreter doesn't do ordinals, this will be set to
@@ -306,4 +306,5 @@
      * @param   pszFile     The filename.
      * @param   cchFile     The length of the filename.
+     * @param   uLineNo     The line number.
      * @param   iSeg        The segment number (0-based).
      * @param   off         The offset into the segment.
Index: /trunk/src/VBox/Runtime/include/internal/rand.h
===================================================================
--- /trunk/src/VBox/Runtime/include/internal/rand.h	(revision 25644)
+++ /trunk/src/VBox/Runtime/include/internal/rand.h	(revision 25645)
@@ -105,5 +105,5 @@
      * @retval  VERR_NOT_SUPPORTED by non-psuedo generators.
      *
-     * @param   hRand       Handle to the random number generator.
+     * @param   pThis       Pointer to the instance data.
      * @param   pszState    Where to store the state. The returned string will be
      *                      null terminated and printable.
@@ -112,5 +112,5 @@
      *                      terminator, thus the 'cb' instead of 'cch').
      */
-    DECLCALLBACKMEMBER(int, pfnSaveState)(RTRAND hRand, char *pszState, size_t *pcbState);
+    DECLCALLBACKMEMBER(int, pfnSaveState)(PRTRANDINT pThis, char *pszState, size_t *pcbState);
 
     /**
@@ -123,8 +123,8 @@
      * @retval  VERR_NOT_SUPPORTED by non-psuedo generators.
      *
-     * @param   hRand       Handle to the random number generator.
+     * @param   pThis       Pointer to the instance data.
      * @param   pszState    The state to load.
      */
-    DECLCALLBACKMEMBER(int, pfnRestoreState)(RTRAND hRand, char const *pszState);
+    DECLCALLBACKMEMBER(int, pfnRestoreState)(PRTRANDINT pThis, char const *pszState);
 
     /**
Index: /trunk/src/VBox/Runtime/r0drv/nt/timer-r0drv-nt.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r0drv/nt/timer-r0drv-nt.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/r0drv/nt/timer-r0drv-nt.cpp	(revision 25645)
@@ -107,5 +107,8 @@
  *
  * @returns HRTIMER_NORESTART or HRTIMER_RESTART depending on whether it's a one-shot or interval timer.
- * @param   pHrTimer    Pointer to the timer structure.
+ * @param   pDpc                Pointer to the the DPC.
+ * @param   pvUser              Pointer to our internal timer structure.
+ * @param   SystemArgument1     Some system argument.
+ * @param   SystemArgument2     Some system argument.
  */
 static void _stdcall rtTimerNtSimpleCallback(IN PKDPC pDpc, IN PVOID pvUser, IN PVOID SystemArgument1, IN PVOID SystemArgument2)
Index: /trunk/src/VBox/Runtime/r3/freebsd/fileaio-freebsd.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/freebsd/fileaio-freebsd.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/r3/freebsd/fileaio-freebsd.cpp	(revision 25645)
@@ -224,8 +224,8 @@
 
 RTDECL(int) RTFileAioReqPrepareWrite(RTFILEAIOREQ hReq, RTFILE hFile, RTFOFF off,
-                                     void *pvBuf, size_t cbWrite, void *pvUser)
+                                     void const *pvBuf, size_t cbWrite, void *pvUser)
 {
     return rtFileAioReqPrepareTransfer(hReq, hFile, LIO_WRITE,
-                                       off, pvBuf, cbWrite, pvUser);
+                                       off, (void *)pvBuf, cbWrite, pvUser);
 }
 
Index: /trunk/src/VBox/Runtime/r3/linux/fileaio-linux.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/linux/fileaio-linux.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/r3/linux/fileaio-linux.cpp	(revision 25645)
@@ -399,8 +399,8 @@
 
 RTDECL(int) RTFileAioReqPrepareWrite(RTFILEAIOREQ hReq, RTFILE hFile, RTFOFF off,
-                                     void *pvBuf, size_t cbWrite, void *pvUser)
+                                     void const *pvBuf, size_t cbWrite, void *pvUser)
 {
     return rtFileAioReqPrepareTransfer(hReq, hFile, LNXKAIO_IOCB_CMD_WRITE,
-                                       off, pvBuf, cbWrite, pvUser);
+                                       off, (void *)pvBuf, cbWrite, pvUser);
 }
 
Index: /trunk/src/VBox/Runtime/r3/posix/fileaio-posix.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/posix/fileaio-posix.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/r3/posix/fileaio-posix.cpp	(revision 25645)
@@ -423,8 +423,8 @@
 
 RTDECL(int) RTFileAioReqPrepareWrite(RTFILEAIOREQ hReq, RTFILE hFile, RTFOFF off,
-                                     void *pvBuf, size_t cbWrite, void *pvUser)
+                                     void const *pvBuf, size_t cbWrite, void *pvUser)
 {
     return rtFileAioReqPrepareTransfer(hReq, hFile, LIO_WRITE,
-                                       off, pvBuf, cbWrite, pvUser);
+                                       off, (void *)pvBuf, cbWrite, pvUser);
 }
 
Index: /trunk/src/VBox/Runtime/r3/solaris/fileaio-solaris.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/solaris/fileaio-solaris.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/r3/solaris/fileaio-solaris.cpp	(revision 25645)
@@ -191,8 +191,8 @@
 
 RTDECL(int) RTFileAioReqPrepareWrite(RTFILEAIOREQ hReq, RTFILE hFile, RTFOFF off,
-                                     void *pvBuf, size_t cbWrite, void *pvUser)
+                                     void const *pvBuf, size_t cbWrite, void *pvUser)
 {
     return rtFileAioReqPrepareTransfer(hReq, hFile, LIO_WRITE,
-                                       off, pvBuf, cbWrite, pvUser);
+                                       off, (void *)pvBuf, cbWrite, pvUser);
 }
 
Index: /trunk/src/VBox/Runtime/r3/test.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/test.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/r3/test.cpp	(revision 25645)
@@ -832,5 +832,5 @@
 
 
-RTR3DECL(int) RTTestSkipAndDestroyV(RTTEST hTest, const char *pszReason, va_list va)
+RTR3DECL(int) RTTestSkipAndDestroyV(RTTEST hTest, const char *pszReasonFmt, va_list va)
 {
     PRTTESTINT pTest = hTest;
@@ -844,6 +844,6 @@
     if (!pTest->cErrors)
     {
-        if (pszReason)
-            RTTestPrintfNlV(hTest, RTTESTLVL_FAILURE, pszReason, va);
+        if (pszReasonFmt)
+            RTTestPrintfNlV(hTest, RTTESTLVL_FAILURE, pszReasonFmt, va);
         RTTestPrintfNl(hTest, RTTESTLVL_ALWAYS, "SKIPPED\n", pTest->cErrors);
         rc = 2;
@@ -860,9 +860,9 @@
 
 
-RTR3DECL(int) RTTestSkipAndDestroy(RTTEST hTest, const char *pszReason, ...)
+RTR3DECL(int) RTTestSkipAndDestroy(RTTEST hTest, const char *pszReasonFmt, ...)
 {
     va_list va;
-    va_start(va, pszReason);
-    int rc = RTTestSkipAndDestroyV(hTest, pszReason, va);
+    va_start(va, pszReasonFmt);
+    int rc = RTTestSkipAndDestroyV(hTest, pszReasonFmt, va);
     va_end(va);
     return rc;
@@ -1129,5 +1129,4 @@
  * @param   hTest       The test handle. If NIL_RTTEST we'll use the one
  *                      associated with the calling thread.
- * @param   enmLevel    Message importance level.
  * @param   pszFormat   The message.
  * @param   va          Arguments.
@@ -1145,5 +1144,4 @@
  * @param   hTest       The test handle. If NIL_RTTEST we'll use the one
  *                      associated with the calling thread.
- * @param   enmLevel    Message importance level.
  * @param   pszFormat   The message.
  * @param   ...         Arguments.
Index: /trunk/src/VBox/Runtime/r3/win/fileaio-win.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/win/fileaio-win.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/r3/win/fileaio-win.cpp	(revision 25645)
@@ -212,8 +212,8 @@
 
 RTDECL(int) RTFileAioReqPrepareWrite(RTFILEAIOREQ hReq, RTFILE hFile, RTFOFF off,
-                                     void *pvBuf, size_t cbWrite, void *pvUser)
+                                     void const *pvBuf, size_t cbWrite, void *pvUser)
 {
     return rtFileAioReqPrepareTransfer(hReq, hFile, TRANSFERDIRECTION_WRITE,
-                                       off, pvBuf, cbWrite, pvUser);
+                                       off, (void *)pvBuf, cbWrite, pvUser);
 }
 
Index: /trunk/src/VBox/Runtime/r3/xml.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/xml.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/r3/xml.cpp	(revision 25645)
@@ -731,5 +731,5 @@
  *
  * @param pcszMatch name of attribute to find.
- * @param str out: attribute value
+ * @param ppcsz out: attribute value
  * @return TRUE if attribute was found and str was thus updated.
  */
@@ -856,5 +856,5 @@
  *
  * @param pcszMatch name of attribute to find.
- * @param i out: attribute value; overwritten only if attribute was found
+ * @param f out: attribute value; overwritten only if attribute was found
  * @return TRUE if attribute was found and str was thus updated.
  */
@@ -921,5 +921,5 @@
  * in "this".
  *
- * @param pcszElementName
+ * @param pcszContent
  * @return
  */
@@ -1078,6 +1078,4 @@
  *          ...;
  * </code>
- * @param node
- * @param pcszMatch
  * @return
  */
@@ -1321,5 +1319,5 @@
  * The document that is passed in will be reset before being filled if not empty.
  *
- * @param pcszFilename in: name fo file to parse.
+ * @param strFilename in: name fo file to parse.
  * @param doc out: document to be reset and filled with data according to file contents.
  */

Index: /trunk/include/iprt/asm.h
===================================================================
--- /trunk/include/iprt/asm.h	(revision 25644)
+++ /trunk/include/iprt/asm.h	(revision 25645)
@@ -34,5 +34,5 @@
 #include <iprt/types.h>
 #include <iprt/assert.h>
-/** @todo #include <iprt/param.h> for PAGE_SIZE. */
+/** @todo @code #include <iprt/param.h> @endcode for PAGE_SIZE. */
 /** @def RT_INLINE_ASM_USES_INTRIN
  * Defined as 1 if we're using a _MSC_VER 1400.
@@ -1049,5 +1049,4 @@
  * @returns Model.
  * @param   uEAX    EAX from ASMCpuId(1) or ASMCpuId(0x80000001).
- * @param   fIntel  Whether it's an intel CPU.
  */
 DECLINLINE(uint32_t) ASMGetCpuModelIntel(uint32_t uEAX)
@@ -1064,5 +1063,4 @@
  * @returns Model.
  * @param   uEAX    EAX from ASMCpuId(1) or ASMCpuId(0x80000001).
- * @param   fIntel  Whether it's an intel CPU.
  */
 DECLINLINE(uint32_t) ASMGetCpuModelAMD(uint32_t uEAX)
@@ -3689,10 +3687,10 @@
  *
  * @returns The old value.
- * @param   pu32        Pointer to the value.
- * @param   u32         Number to subtract.
- */
-DECLINLINE(uint32_t) ASMAtomicSubU32(int32_t volatile *pi32, uint32_t u32)
-{
-    return ASMAtomicAddU32((uint32_t volatile *)pi32, (uint32_t)-(int32_t)u32);
+ * @param   pi32        Pointer to the value.
+ * @param   i32         Number to subtract.
+ */
+DECLINLINE(uint32_t) ASMAtomicSubU32(int32_t volatile *pi32, uint32_t i32)
+{
+    return ASMAtomicAddU32((uint32_t volatile *)pi32, (uint32_t)-(int32_t)i32);
 }
 
Index: /trunk/include/iprt/dbg.h
===================================================================
--- /trunk/include/iprt/dbg.h	(revision 25644)
+++ /trunk/include/iprt/dbg.h	(revision 25645)
@@ -512,8 +512,8 @@
  * @param   poffDisp        Where to return the distance between the symbol
  *                          and address. Optional.
  * @param   pSymInfo        Where to return the symbol info.
  * @param   phMod           Where to return the module handle. Optional.
  */
-RTDECL(int) RTDbgAsSymbolByAddr(RTDBGAS hDbgAs, RTUINTPTR Addr, PRTINTPTR poffDisp, PRTDBGSYMBOL pSymInfo, PRTDBGMOD phMod);
+RTDECL(int) RTDbgAsSymbolByAddr(RTDBGAS hDbgAs, RTUINTPTR Addr, PRTINTPTR poffDisp, PRTDBGSYMBOL pSymbol, PRTDBGMOD phMod);
 
 /**
@@ -1100,5 +1100,5 @@
  *                              specified address and the returned symbol.
  *                              Optional.
- * @param   pSymInfo            Where to store the symbol information.
+ * @param   pLineInfo           Where to store the line number information.
  */
 RTDECL(int)         RTDbgModLineByAddr(RTDBGMOD hDbgMod, RTDBGSEGIDX iSeg, RTUINTPTR off, PRTINTPTR poffDisp, PRTDBGLINE pLineInfo);
@@ -512,8 +512,8 @@
  * @param   poffDisp        Where to return the distance between the symbol
  *                          and address. Optional.
- * @param   pSymInfo        Where to return the symbol info.
+ * @param   pSymbol         Where to return the symbol info.
  * @param   phMod           Where to return the module handle. Optional.
  */
Index: /trunk/src/VBox/Runtime/common/dbg/dbgas.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/dbg/dbgas.cpp	(revision 25644)
+++ /trunk/src/VBox/Runtime/common/dbg/dbgas.cpp	(revision 25645)
@@ -1167,6 +1167,6 @@
  * Adjusts the address to correspond to the mapping of the module/segment.
  *
- * @param   pSymbol         The returned symbol info.
- * @param   pMap            The mapping record.
+ * @param   pAddr           The address to adjust (in/out).
+ * @param   iSeg            The related segment.
  * @param   hDbgMod         The module handle.
  * @param   MapAddr         The mapping address.
@@ -1259,4 +1259,7 @@
  * @param   cb              The size of the symbol.
  * @param   fFlags          Symbol flags.
+ * @param   piOrdinal       Where to return the symbol ordinal on success. If
+ *                          the interpreter doesn't do ordinals, this will be set to
+ *                          UINT32_MAX. Optional
  */
 RTDECL(int) RTDbgAsSymbolAdd(RTDBGAS hDbgAs, const char *pszSymbol, RTUINTPTR Addr, RTUINTPTR cb, uint32_t fFlags, uint32_t *piOrdinal)
@@ -1343,9 +1346,9 @@
  * @param   poffDisp        Where to return the distance between the symbol
  *                          and address. Optional.
  * @param   ppSymbol        Where to return the pointer to the allocated
  *                          symbol info. Always set. Free with RTDbgSymbolFree.
  * @param   phMod           Where to return the module handle. Optional.
  */
-RTDECL(int) RTDbgAsSymbolByAddrA(RTDBGAS hDbgAs, RTUINTPTR Addr, PRTINTPTR poffDisp, PRTDBGSYMBOL *ppSymbol, PRTDBGMOD phMod)
+RTDECL(int) RTDbgAsSymbolByAddrA(RTDBGAS hDbgAs, RTUINTPTR Addr, PRTINTPTR poffDisp, PRTDBGSYMBOL *ppSymInfo, PRTDBGMOD phMod)
 {
     /*
@@ -1369,7 +1372,7 @@
      * Forward the call.
      */
-    int rc = RTDbgModSymbolByAddrA(hMod, iSeg, offSeg, poffDisp, ppSymbol);
+    int rc = RTDbgModSymbolByAddrA(hMod, iSeg, offSeg, poffDisp, ppSymInfo);
     if (RT_SUCCESS(rc))
-        rtDbgAsAdjustSymbolValue(*ppSymbol, hMod, MapAddr, iSeg);
+        rtDbgAsAdjustSymbolValue(*ppSymInfo, hMod, MapAddr, iSeg);
     if (phMod)
         *phMod = hMod;
@@ -1343,9 +1346,9 @@
  * @param   poffDisp        Where to return the distance between the symbol
  *                          and address. Optional.
- * @param   ppSymbol        Where to return the pointer to the allocated
- *                          symbol info. Always set. Free with RTDbgSymbolFree.
+ * @param   ppSymInfo       Where to return the pointer to the allocated symbol
+ *                          info. Always set. Free with RTDbgSymbolFree.
  * @param   phMod           Where to return the module handle. Optional.
  */